<?php
/**
 * Custom Posts Portfolios.
 *
 * @package HND Plugins
 */

defined( 'ABSPATH' ) || die();

/**
 * HND Plugins Custom Post Portfolios Class.
 *
 * Description.
 *
 * @since 1.0.0
 */
class Hnd_Plugins_Cpt_Portfolios {

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'register_hnd_cpt_portfolio' ) );
		add_action( 'init', array( $this, 'register_hnd_cpt_portfolio_categories' ) );
		add_action( 'init', array( $this, 'register_hnd_cpt_portfolio_tags' ) );
		add_filter( 'single_template', array( $this, 'cpt_portfolio_single_template' ) );
	}

	/**
	 * Register Custom Post Portfolio.
	 *
	 * @since 1.0.0
	 */
	public function register_hnd_cpt_portfolio() {
		/**
		 * Post Type: Portfolios.
		 */

		$labels = array(
			'name'          => __( 'Portfolios', 'hnd-plugins' ),
			'singular_name' => __( 'Portfolio', 'hnd-plugins' ),
			'menu_name'     => __( 'Portfolios', 'hnd-plugins' ),
		);

		$args = array(
			'label'                 => __( 'Portfolios', 'hnd-plugins' ),
			'labels'                => $labels,
			'description'           => 'This type of post is used to create a portfolio',
			'public'                => true,
			'publicly_queryable'    => true,
			'show_ui'               => true,
			'delete_with_user'      => false,
			'show_in_rest'          => true,
			'rest_base'             => '',
			'rest_controller_class' => 'WP_REST_Posts_Controller',
			'has_archive'           => true,
			'show_in_menu'          => true,
			'show_in_nav_menus'     => true,
			'exclude_from_search'   => false,
			'capability_type'       => 'post',
			'map_meta_cap'          => true,
			'hierarchical'          => false,
			'rewrite'               => array(
				'slug'       => 'portfolio',
				'with_front' => true,
			),
			'query_var'             => true,
			'supports'              => array( 'title', 'editor', 'thumbnail', 'excerpt', 'custom-fields' ),
			'show_in_rest'          => true,
		);

		register_post_type( 'portfolio', $args );
	}

	/**
	 * Register Custom Post Portfolio Categories.
	 *
	 * @since 1.0.0
	 */
	public function register_hnd_cpt_portfolio_categories() {
		/**
		 * Taxonomy: Portfolio Categories.
		 */
		$labels = array(
			'name'          => __( 'Portfolio Categories', 'hnd-plugins' ),
			'singular_name' => __( 'Portfolio Category', 'hnd-plugins' ),
			'not_found'     => __( 'No category found', 'hnd-plugins' ),
		);

		$args = array(
			'label'                 => __( 'Portfolio Categories', 'hnd-plugins' ),
			'labels'                => $labels,
			'public'                => true,
			'publicly_queryable'    => true,
			'hierarchical'          => false,
			'show_ui'               => true,
			'show_in_menu'          => true,
			'show_in_nav_menus'     => true,
			'query_var'             => true,
			'rewrite'               => array(
				'slug'       => 'portfolio_category',
				'with_front' => true,
			),
			'show_admin_column'     => false,
			'show_in_rest'          => true,
			'rest_base'             => 'portfolio_category',
			'rest_controller_class' => 'WP_REST_Terms_Controller',
			'show_in_quick_edit'    => false,
		);
		register_taxonomy( 'portfolio_category', array( 'portfolio' ), $args );
	}

	/**
	 * Register Custom Post Portfolio Tags.
	 *
	 * @since 1.0.0
	 */
	public function register_hnd_cpt_portfolio_tags() {
		/**
		 * Taxonomy: Portfolio Tags.
		 */
		$labels = array(
			'name'          => __( 'Portfolio Tags', 'hnd-plugins' ),
			'singular_name' => __( 'Portfolio Tag', 'hnd-plugins' ),
		);

		$args = array(
			'label'                 => __( 'Portfolio Tags', 'hnd-plugins' ),
			'labels'                => $labels,
			'public'                => true,
			'publicly_queryable'    => true,
			'hierarchical'          => false,
			'show_ui'               => true,
			'show_in_menu'          => true,
			'show_in_nav_menus'     => true,
			'query_var'             => true,
			'rewrite'               => array(
				'slug'       => 'portfolio_tags',
				'with_front' => true,
			),
			'show_admin_column'     => false,
			'show_in_rest'          => true,
			'rest_base'             => 'portfolio_tags',
			'rest_controller_class' => 'WP_REST_Terms_Controller',
			'show_in_quick_edit'    => false,
		);
		register_taxonomy( 'portfolio_tags', array( 'portfolio' ), $args );
	}

	/**
	 * Custom Post Portfolio Single Template.
	 *
	 * @since 1.0.0
	 *
	 * @param string $template   Template File URL.
	 */
	public function cpt_portfolio_single_template( $template ) {

		if ( is_singular( 'portfolio' ) ) {
			$template = HND_PLUGIN_DIR . 'inc/custom-post/portfolio/templates/single-portfolio.php';
		}

		return $template;
	}
}
