<?php
/**
 * Custom Posts Press.
 *
 * @package HND Plugins
 */

defined( 'ABSPATH' ) || die();

/**
 * HND Plugins Custom Post Press Class.
 *
 * Description.
 *
 * @since 1.0.0
 */
class Hnd_Plugins_Cpt_Press {

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'register_hnd_cpt_press' ) );
		add_action( 'init', array( $this, 'register_hnd_cpt_press_categories' ) );
		add_action( 'init', array( $this, 'register_hnd_cpt_press_tags' ) );
		add_filter( 'single_template', array( $this, 'cpt_press_single_template' ) );
	}

	/**
	 * Register Custom Post Press.
	 *
	 * @since 1.0.0
	 */
	public function register_hnd_cpt_press() {
		/**
		 * Post Type: Press.
		 */
		$labels = array(
			'name'                  => __( 'Press', 'hnd-plugins' ),
			'singular_name'         => __( 'Press', 'hnd-plugins' ),
			'menu_name'             => __( 'Press', 'hnd-plugins' ),
			'all_items'             => __( 'All Press', 'hnd-plugins' ),
			'add_new'               => __( 'Add New', 'hnd-plugins' ),
			'add_new_item'          => __( 'Add New Press', 'hnd-plugins' ),
			'edit_item'             => __( 'Edit Press', 'hnd-plugins' ),
			'new_item'              => __( 'New Press', 'hnd-plugins' ),
			'view_item'             => __( 'View Press', 'hnd-plugins' ),
			'view_items'            => __( 'View Press', 'hnd-plugins' ),
			'search_items'          => __( 'Search Press', 'hnd-plugins' ),
			'not_found'             => __( 'No Press found', 'hnd-plugins' ),
			'not_found_in_trash'    => __( 'No Press found in trash', 'hnd-plugins' ),
			'featured_image'        => __( 'Featured Image for Press', 'hnd-plugins' ),
			'set_featured_image'    => __( 'Set featured Image for Press', 'hnd-plugins' ),
			'remove_featured_image' => __( 'Remove featured image for Press', 'hnd-plugins' ),
			'use_featured_image'    => __( 'Use as featured Image for this Press', 'hnd-plugins' ),
		);

		$args = array(
			'label'                 => __( 'Press', 'hnd-plugins' ),
			'labels'                => $labels,
			'description'           => '',
			'public'                => true,
			'publicly_queryable'    => true,
			'show_ui'               => true,
			'delete_with_user'      => false,
			'show_in_rest'          => true,
			'rest_base'             => '',
			'rest_controller_class' => 'WP_REST_Posts_Controller',
			'has_archive'           => false,
			'show_in_menu'          => true,
			'show_in_nav_menus'     => true,
			'exclude_from_search'   => false,
			'capability_type'       => 'post',
			'map_meta_cap'          => true,
			'hierarchical'          => true,
			'rewrite'               => array(
				'slug'       => 'press',
				'with_front' => false,
			),
			'query_var'             => true,
			'supports'              => array( 'title', 'editor', 'thumbnail', 'excerpt', 'custom-fields', 'revisions', 'author', 'page-attributes' ),
			'taxonomies'            => array( 'Press_category', 'Press_tags' ),
			'show_in_rest'          => true,
		);

		register_post_type( 'press', $args );
	}

	/**
	 * Register Custom Post Press Categories.
	 *
	 * @since 1.0.0
	 */
	public function register_hnd_cpt_press_categories() {
		/**
		 * Taxonomy: Press Categories.
		 */
		$labels = array(
			'name'          => __( 'Press Categories', 'hnd-plugins' ),
			'singular_name' => __( 'Press Category', 'hnd-plugins' ),
			'not_found'     => __( 'No category found', 'hnd-plugins' ),
		);

		$args = array(
			'label'                 => __( 'Press Categories', 'hnd-plugins' ),
			'labels'                => $labels,
			'public'                => true,
			'publicly_queryable'    => true,
			'hierarchical'          => false,
			'show_ui'               => true,
			'show_in_menu'          => true,
			'show_in_nav_menus'     => true,
			'query_var'             => true,
			'rewrite'               => array(
				'slug'       => 'press_category',
				'with_front' => true,
			),
			'show_admin_column'     => false,
			'show_in_rest'          => true,
			'rest_base'             => 'press_category',
			'rest_controller_class' => 'WP_REST_Terms_Controller',
			'show_in_quick_edit'    => false,
		);
		register_taxonomy( 'press_category', array( 'press' ), $args );
	}

	/**
	 * Register HND Custom Post Press Tags.
	 *
	 * @since 1.0.0
	 */
	public function register_hnd_cpt_press_tags() {
		/**
		 * Taxonomy: Press Tags.
		 */
		$labels = array(
			'name'          => __( 'Press Tags', 'hnd-plugins' ),
			'singular_name' => __( 'Press Tag', 'hnd-plugins' ),
		);

		$args = array(
			'label'                 => __( 'Press Tags', 'hnd-plugins' ),
			'labels'                => $labels,
			'public'                => true,
			'publicly_queryable'    => true,
			'hierarchical'          => false,
			'show_ui'               => true,
			'show_in_menu'          => true,
			'show_in_nav_menus'     => true,
			'query_var'             => true,
			'rewrite'               => array(
				'slug'       => 'press_tags',
				'with_front' => true,
			),
			'show_admin_column'     => false,
			'show_in_rest'          => true,
			'rest_base'             => 'press_tags',
			'rest_controller_class' => 'WP_REST_Terms_Controller',
			'show_in_quick_edit'    => false,
		);
		register_taxonomy( 'press_tags', array( 'press' ), $args );
	}

	/**
	 * Custom Post Press Single Template.
	 *
	 * @since 1.0.0
	 *
	 * @param string $template   Template File URL.
	 */
	public function cpt_press_single_template( $template ) {

		if ( is_singular( 'press' ) ) {
			$template = HND_PLUGIN_DIR . 'inc/custom-post/press/templates/single-press.php';
		}

		return $template;
	}
}
