<?php
/**
 * Custom Posts Services.
 *
 * @package HND Plugins
 */

defined( 'ABSPATH' ) || die();

/**
 * HND Plugins Custom Post Services Class.
 *
 * Description.
 *
 * @since 1.0.0
 */
class Hnd_Plugins_Cpt_Services {

	/**
	 * Constructor.
	 *
	 * @since 1.0.0
	 */
	public function __construct() {
		add_action( 'init', array( $this, 'register_hnd_cpt_service' ) );
		add_action( 'init', array( $this, 'register_hnd_cpt_service_categories' ) );
		add_action( 'init', array( $this, 'register_hnd_cpt_service_tags' ) );
		add_filter( 'single_template', array( $this, 'cpt_service_single_template' ) );
		add_theme_support( 'post-thumbnails' );
	}

	/**
	 * Register Custom Post Service.
	 *
	 * @since 1.0.0
	 */
	public function register_hnd_cpt_service() {
		/**
		 * Post Type: Services.
		 */
		$labels = array(
			'name'                  => __( 'Services', 'hnd-plugins' ),
			'singular_name'         => __( 'Service', 'hnd-plugins' ),
			'menu_name'             => __( 'Services', 'hnd-plugins' ),
			'all_items'             => __( 'All Services', 'hnd-plugins' ),
			'add_new'               => __( 'Add New', 'hnd-plugins' ),
			'add_new_item'          => __( 'Add New Service', 'hnd-plugins' ),
			'edit_item'             => __( 'Edit Service', 'hnd-plugins' ),
			'new_item'              => __( 'New Service', 'hnd-plugins' ),
			'view_item'             => __( 'View Service', 'hnd-plugins' ),
			'view_items'            => __( 'View Services', 'hnd-plugins' ),
			'search_items'          => __( 'Search Service', 'hnd-plugins' ),
			'not_found'             => __( 'No Services found', 'hnd-plugins' ),
			'not_found_in_trash'    => __( 'No Services found in trash', 'hnd-plugins' ),
			'featured_image'        => __( 'Featured Image for Service', 'hnd-plugins' ),
			'set_featured_image'    => __( 'Set featured Image for Service', 'hnd-plugins' ),
			'remove_featured_image' => __( 'Remove featured image for Service', 'hnd-plugins' ),
			'use_featured_image'    => __( 'Use as featured Image for this Service', 'hnd-plugins' ),
		);

		$args = array(
			'label'                 => __( 'Services', 'hnd-plugins' ),
			'labels'                => $labels,
			'description'           => '',
			'public'                => true,
			'publicly_queryable'    => true,
			'show_ui'               => true,
			'delete_with_user'      => false,
			'show_in_rest'          => true,
			'rest_base'             => '',
			'rest_controller_class' => 'WP_REST_Posts_Controller',
			'has_archive'           => false,
			'show_in_menu'          => true,
			'show_in_nav_menus'     => true,
			'exclude_from_search'   => false,
			'capability_type'       => 'post',
			'map_meta_cap'          => true,
			'hierarchical'          => true,
			'rewrite'               => array(
				'slug'       => 'service',
				'with_front' => false,
			),
			'query_var'             => true,
			'supports'              => array( 'title', 'editor', 'thumbnail', 'excerpt', 'custom-fields', 'revisions', 'author', 'page-attributes' ),
			'taxonomies'            => array( 'service_category', 'service_tags' ),
			'show_in_rest'          => true,
		);

		register_post_type( 'service', $args );
		add_filter( 'manage_edit-service_columns', array( $this, 'hnd_show_service_column' ) );
		add_action( 'manage_pages_custom_column', array( $this, 'hnd_port_custom_columns' ) );
	}

	/**
	 * Custom Post List.
	 *
	 * @since 1.0.0
	 *
	 * @param string $columns   Column List.
	 */
	public function hnd_show_service_column( $columns ) {

		$columns = array(
			'cb'              => '<input type="checkbox" />',
			'image'           => __( 'Image', 'hnd-plugins' ),
			'title'           => __( 'Title', 'hnd-plugins' ),
			'author'          => __( 'Author', 'hnd-plugins' ),
			'dtpost-category' => __( 'Categories', 'hnd-plugins' ),
			'date'            => __( 'Date', 'hnd-plugins' ),
		);
		return $columns;
	}

	/**
	 * Add Image Column to Custom Post List.
	 *
	 * @since 1.0.0
	 *
	 * @param string $column   Image at First Column List.
	 */
	public function hnd_port_custom_columns( $column ) {

		global $post;
		switch ( $column ) {
			case 'service-category':
				echo get_the_term_list( $post->ID, 'service_category', '', ', ', '' );
				break;
			case 'image':
				$attachment_id = get_the_post_thumbnail( $post->ID, 'thumbnail' );
				print ( $attachment_id ) ? $attachment_id : '';
				break;
		}
	}

	/**
	 * Register Custom Post Service Categories.
	 *
	 * @since 1.0.0
	 */
	public function register_hnd_cpt_service_categories() {
		/**
		 * Taxonomy: Service Categories.
		 */
		$labels = array(
			'name'          => __( 'Service Categories', 'hnd-plugins' ),
			'singular_name' => __( 'Service Category', 'hnd-plugins' ),
			'not_found'     => __( 'No category found', 'hnd-plugins' ),
		);

		$args = array(
			'label'                 => __( 'Service Categories', 'hnd-plugins' ),
			'labels'                => $labels,
			'public'                => true,
			'publicly_queryable'    => true,
			'hierarchical'          => false,
			'show_ui'               => true,
			'show_in_menu'          => true,
			'show_in_nav_menus'     => true,
			'query_var'             => true,
			'rewrite'               => array(
				'slug'       => 'service_category',
				'with_front' => true,
			),
			'show_admin_column'     => false,
			'show_in_rest'          => true,
			'rest_base'             => 'service_category',
			'rest_controller_class' => 'WP_REST_Terms_Controller',
			'show_in_quick_edit'    => false,
		);
		register_taxonomy( 'service_category', array( 'service' ), $args );
	}

	/**
	 * Register HND Custom Post Service Tags.
	 *
	 * @since 1.0.0
	 */
	public function register_hnd_cpt_service_tags() {
		/**
		 * Taxonomy: Service Tags.
		 */
		$labels = array(
			'name'          => __( 'Service Tags', 'hnd-plugins' ),
			'singular_name' => __( 'Service Tag', 'hnd-plugins' ),
		);

		$args = array(
			'label'                 => __( 'Service Tags', 'hnd-plugins' ),
			'labels'                => $labels,
			'public'                => true,
			'publicly_queryable'    => true,
			'hierarchical'          => false,
			'show_ui'               => true,
			'show_in_menu'          => true,
			'show_in_nav_menus'     => true,
			'query_var'             => true,
			'rewrite'               => array(
				'slug'       => 'service_tags',
				'with_front' => true,
			),
			'show_admin_column'     => false,
			'show_in_rest'          => true,
			'rest_base'             => 'service_tags',
			'rest_controller_class' => 'WP_REST_Terms_Controller',
			'show_in_quick_edit'    => false,
		);
		register_taxonomy( 'service_tags', array( 'service' ), $args );
	}

	/**
	 * Custom Post Service Single Template.
	 *
	 * @since 1.0.0
	 *
	 * @param string $template   Template File URL.
	 */
	public function cpt_service_single_template( $template ) {

		if ( is_singular( 'service' ) ) {
			$template = HND_PLUGIN_DIR . 'inc/custom-post/service/templates/single-service.php';
		}

		return $template;
	}
}
