<?php
/**
 * Customizer option and render to frontend.
 *
 * @package HND Plugin
 */

require_once HND_PLUGIN_DIR . '/inc/simple-line-icons.php';

if ( ! function_exists( 'hnd_plugin_customizer_settings' ) ) :

	/**
	 * This file config for customizer.
	 *
	 * @param object $wp_customize  WP Customize object.
	 */
	function hnd_plugin_customizer_settings( $wp_customize ) {
		global $hnd_customizer_settings, $hnd_customizer_sections;

		if ( ! isset( $hnd_customizer_settings ) || ! isset( $hnd_customizer_sections ) ) {
			return;
		}

		// HND Navigation Bar.
		$hnd_customizer_sections['hnd-addon-menu-option'] = array(
			'title'    => esc_html__( 'HND Navigation Bar', 'hnd-plugins' ),
			'panel'    => '',
			'priority' => 21,
		);

		$hnd_customizer_sections['hnd-addon-content-option'] = array(
			'title'    => esc_html__( 'HND Content Options', 'hnd-plugins' ),
			'panel'    => '',
			'priority' => 22,
		);

		$hnd_customizer_settings['hnd-nav-layout'] = array(
			'section'     => 'hnd-addon-menu-option',
			'type'        => 'custom',
			'custom_type' => 'hnd-switcher',
			'default'     => 'hnd-menu-default',
			'label'       => esc_html__( 'Navigation Layout', 'hnd-plugins' ),
			'transport'   => 'refresh',
			'choices'     => array(
				'hnd-menu-default' => esc_html__( 'Default', 'hnd-plugins' ),
				'hnd-menu-stretch' => esc_html__( 'Stretch', 'hnd-plugins' ),
				'hnd-menu-center'  => esc_html__( 'Center', 'hnd-plugins' ),
			),
		);

		$hnd_customizer_settings['hnd-box-arround'] = array(
			'section'     => 'hnd-addon-menu-option',
			'type'        => 'custom',
			'custom_type' => 'hnd-switcher',
			'default'     => 'on',
			'label'       => esc_html__( 'Box Arround Layout', 'hnd-plugins' ),
			'transport'   => 'refresh',
			'choices'     => array(
				'off' => esc_html__( 'Off', 'hnd-plugins' ),
				'on'  => esc_html__( 'On', 'hnd-plugins' ),
			),
		);

		$hnd_customizer_settings['hnd-addon-background-color'] = array(
			'section'      => 'hnd-addon-menu-option',
			'type'         => 'color-alpha',
			'default'      => '#f3f3f3',
			'capability'   => 'edit_theme_options',
			'transport'    => 'refresh',
			'show_opacity' => false,
			'label'        => esc_html__( 'Background Color', 'hnd-plugins' ),
		);

		$hnd_customizer_settings['hnd-disable-breadcrumb'] = array(
			'section'     => 'hnd-addon-content-option',
			'type'        => 'custom',
			'custom_type' => 'hnd-switcher',
			'default'     => 'block',
			'label'       => esc_html__( 'Enable/Disable Background', 'hnd-plugins' ),
			'transport'   => 'refresh',
			'choices'     => array(
				'none'  => esc_html__( 'Off', 'hnd-plugins' ),
				'block' => esc_html__( 'On', 'hnd-plugins' ),
			),
		);

	}

	add_action( 'customize_register', 'hnd_plugin_customizer_settings' );
endif;

if ( ! function_exists( 'hnd_render_settings' ) ) :

	/**
	 * This is function to retrieve and render customizer settings on frontend.
	 */
	function hnd_render_settings() {
		$css = array();

		wp_enqueue_style( 'hnd-plugins-style', HND_PLUGIN_URL . 'assets/css/plugins.min.css' );

		if ( has_custom_logo() ) {
			$css[] = array(
				'element' => '#header-ext .navbar-wrapper .logo-container a.custom-logo-link img',
				'rules'   => array(
					'max-height' => hnd_plugin_setting( 'logo-height' ) . 'px',
				),
			);
		}

		if ( hnd_plugin_setting( 'hnd-addon-navbar-logo-background' ) ) {
			$css[] = array(
				'element' => '#header-ext .navbar-wrapper .logo-container',
				'rules'   => array(
					'background-color' => get_theme_mod( 'hnd-addon-navbar-logo-background' ),
				),
			);
		}

		if ( hnd_plugin_setting( 'hnd-addon-menu-font-color' ) ) {
			$css[] = array(
				'element' => '.navbar-nav>.menu-item:not(#mobile_navigation)>a, .navbar-nav>.menu-item:not(#mobile_navigation)',
				'rules'   => array(
					'color' => get_theme_mod( 'hnd-addon-menu-font-color' ) . '!important',
				),
			);
		}

		if ( hnd_plugin_setting( 'hnd-addon-background-color' ) ) {
			$css[] = array(
				'element' => '#page',
				'rules'   => array(
					'background-color' => get_theme_mod( 'hnd-addon-background-color' ) . '!important',
				),
			);
		}

		if ( hnd_plugin_setting( 'hnd-addon-navigation-bar-background-color' ) ) {
			$css[] = array(
				'element' => '#header-ext .navbar-wrapper .navigation-container .navigation-item, #navbardesktop',
				'rules'   => array(
					'background-color' => get_theme_mod( 'hnd-addon-navigation-bar-background-color' ) . '!important',
				),
			);
		}

		if ( hnd_plugin_setting( 'hnd-addon-navigation-separator' ) === 'show' ) {
			$css[] = array(
				'element' => '#header-ext .navbar-wrapper .navigation-container .navigation-button-container .navigation-button',
				'rules'   => array(
					'border-bottom' => hnd_plugin_setting( 'hnd-addon-navigation-separator-color' ) . ' 1px solid',
				),
			);
		} else {
			$css[] = array(
				'element' => '#header-ext .navbar-wrapper .navigation-container .navigation-button-container .navigation-button',
				'rules'   => array(
					'border-bottom' => 'none',
				),
			);
		}

		if ( hnd_plugin_setting( 'hnd-addon-navigation-info-background-color' ) ) {
			$css[] = array(
				'element' => '#header-ext .navbar-wrapper .navigation-container .navigation-button-container',
				'rules'   => array(
					'background-color' => hnd_plugin_setting( 'hnd-addon-navigation-info-background-color' ),
				),
			);
		}

		if ( hnd_plugin_setting( 'hnd-addon-navigation-info-icon-color' ) ) {
			$css[] = array(
				'element' => '#header-ext .navbar-wrapper .navigation-container .navigation-button-container .navigation-button .navigation-button-item i::before',
				'rules'   => array(
					'color' => hnd_plugin_setting( 'hnd-addon-navigation-info-icon-color' ),
				),
			);
		}

		if ( hnd_plugin_setting( 'hnd-disable-breadcrumb' ) ) {
			$css[] = array(
				'element' => '#page>.breadcrumbs',
				'rules'   => array(
					'display' => hnd_plugin_setting( 'hnd-disable-breadcrumb' ),
				),
			);
		}

		if ( hnd_plugin_setting( 'hnd-addon-navigation-info-text-color' ) ) {
			$css[] = array(
				'element' => '#header-ext .navbar-wrapper .navigation-container .navigation-button-container .navigation-button .navigation-button-item .text-box .navigation-text',
				'rules'   => array(
					'color' => hnd_plugin_setting( 'hnd-addon-navigation-info-text-color' ),
				),
			);

			$css[] = array(
				'element' => '#header-ext .navbar-wrapper .navigation-container .navigation-button-container .navigation-button .navigation-button-item .text-box .navigation-label',
				'rules'   => array(
					'color' => hnd_plugin_setting( 'hnd-addon-navigation-info-text-color' ),
				),
			);
		}

		if ( has_header_image() ) {
			$css[] = array(
				'element' => '#header-image-bg',
				'rules'   => array(
					'background-image' => 'url(' . get_header_image() . ')',
				),
			);

			$css[] = array(
				'element' => '.breadcrumbs',
				'rules'   => array(
					'margin-top' => '0',
				),
			);
		} else {
			$css[] = array(
				'element' => '.breadcrumbs',
				'rules'   => array(
					'margin-top' => '0',
				),
			);

			$css[] = array(
				'element' => '#header-image #header-image-none',
				'rules'   => array(
					'background-color' => '#eeeeee',
				),
			);

			$css[] = array(
				'element' => '#header-image #header-image-none',
				'rules'   => array(
					'display' => 'block',
				),
			);

			$css[] = array(
				'element' => '#header-image #header-image-none',
				'rules'   => array(
					'height' => '100px',
				),
			);
		}

		// Check if quadmenu  inactive.
		if ( ! class_exists( 'Quadmenu' ) ) {
			$css[] = array(
				'element' => '#header-ext .navbar-wrapper .navigation-container .navigation-item',
				'rules'   => array(
					'padding' => '24px',
				),
			);
		} else {
			$css[] = array(
				'element' => 'nav#quadmenu',
				'rules'   => array(
					'padding' => '0 24px',
				),
			);
		}

		// If it's not the same with default value.
		$topbar_home_background_color = hnd_plugin_setting( 'hnd-addon-top-bar-background-color' );
		if ( hnd_plugin_setting( 'hnd-addon-top-bar-background-color', true ) !== $topbar_home_background_color ) {
			$css[] = array(
				'element' => '.topbar-desktop.hnd-plugin-topbar',
				'rules'   => array(
					'background-color' => $topbar_home_background_color,
				),
			);

			$css[] = array(
				'element' => '#header-image #header-image-none',
				'rules'   => array(
					'background-color' => $topbar_home_background_color,
				),
			);
		}

		$css_output = array();

		foreach ( $css as $_css ) {
			$css_output[] = $_css['element'] . '{';

			foreach ( $_css['rules'] as $rule => $props ) {
				$css_output[] = $rule . ':' . $props;
			}

			$css_output[] = '}';
		}

		wp_add_inline_style( 'hnd-plugins-style', implode( '', $css_output ) );
	}

	add_action( 'wp_enqueue_scripts', 'hnd_render_settings' );
endif;
