<?php
/**
 * The Hooks
 *
 * @package HND
 */

if ( ! function_exists( 'hnd_plugin_enqueue_scripts' ) ) :

	/**
	 * Enqueue plugin styles.
	 */
	function hnd_plugin_enqueue_scripts() {
		wp_register_script( 'hnd-plugins-script', HND_PLUGIN_URL . 'assets/js/plugins.min.js', array( 'jquery' ), null, true );
		wp_register_style( 'hnd-plugins-style', HND_PLUGIN_URL . 'assets/css/plugins.min.css' );
		wp_register_style( 'simple-line-icons', HND_PLUGIN_URL . 'assets/css/simple-line-icons.css' );
		wp_register_style( 'social-icons', HND_PLUGIN_URL . 'assets/css/social-icons.css' );
		wp_register_style( 'hnd-flaticon', HND_PLUGIN_URL . 'assets/css/flaticon.css' );

		wp_enqueue_style( 'hnd-plugins-style' );
		wp_enqueue_style( 'social-icons' );
		wp_enqueue_style( 'simple-line-icons' );
		wp_enqueue_style( 'hnd-flaticon' );
		wp_enqueue_script( 'hnd-plugins-script' );

		/**
		 * Load Vendor Icon Picker.
		 */
		if ( 'genericon' === hnd_plugin_setting( 'test-icon-picker', true, 'iconset' ) ) {
			wp_enqueue_style( 'genericons', get_theme_file_uri( '/inc/customizer/assets/vendor/icon-picker/css/genericons/genericons.css' ), array(), null );
		}
		if ( 'dashicon' === hnd_plugin_setting( 'test-icon-picker', true, 'iconset' ) ) {
			wp_enqueue_style( 'dashicons' );
		}
		if ( 'fa' === hnd_plugin_setting( 'test-icon-picker', true, 'iconset' ) ) {
			wp_enqueue_style( 'font-awesome', get_theme_file_uri( '/inc/customizer/assets/vendor/icon-picker/css/font-awesome/css/font-awesome.min.css' ), array(), null );
		}
	}

	add_action( 'wp_enqueue_scripts', 'hnd_plugin_enqueue_scripts' );
endif;

if ( ! function_exists( 'hnd_plugin_admin_enqueue_scripts' ) ) :

	/**
	 * Enqueue plugin styles.
	 */
	function hnd_plugin_admin_enqueue_scripts() {
		wp_register_style( 'simple-line-icons', HND_PLUGIN_URL . 'assets/css/simple-line-icons.css' );
		wp_register_style( 'social-icons', HND_PLUGIN_URL . 'assets/css/social-icons.css' );
		wp_register_script( 'hnd-plugins-script', HND_PLUGIN_URL . 'assets/js/plugins.min.js', array( 'jquery' ), null, true );

		wp_enqueue_style( 'social-icons' );
		wp_enqueue_style( 'simple-line-icons' );
		wp_enqueue_script( 'hnd-plugins-script' );
	}

	add_action( 'admin_enqueue_scripts', 'hnd_plugin_admin_enqueue_scripts' );
endif;

if ( ! function_exists( 'hnd_deregister_scripts' ) ) :

	/**
	 * Deregister theme scripts.
	 */
	function remove_footer_scripts() {
		if ( hnd_plugin_setting( 'hnd-alt-navigation-option' ) === 'on' ) {
			wp_deregister_script( 'sticky-header' );
		}
	}

	add_action( 'wp_footer', 'remove_footer_scripts', 10, 2 );
endif;

if ( ! function_exists( 'replace_hnd_header_template' ) ) :

	/**
	 * Replace existing header.
	 */
	function replace_hnd_header_template() {
		include HND_PLUGIN_DIR . '/templates-parts/header/layout.php';
		include HND_PLUGIN_DIR . '/templates-parts/header/banner.php';
	}
endif;

if ( ! function_exists( 'remove_theme_header' ) ) :

	/**
	 * Remove header action.
	 */
	function remove_theme_header() {
		remove_action( 'hnd_header', 'hnd_header_template', 10, 2 );
	}
endif;

if ( ! function_exists( 'hnd_plugin_get_header' ) ) :

	/**
	 * Replace header action.
	 */
	function hnd_plugin_get_header() {
		if ( hnd_plugin_setting( 'hnd-alt-navigation-option' ) === 'on' ) {
			add_action( 'hnd_header', 'replace_hnd_header_template', 10 );
			add_action( 'hnd_header', 'remove_theme_header', 9 );
		}
	}

	add_action( 'get_header', 'hnd_plugin_get_header' );
endif;

if ( ! function_exists( 'hnd_metabox_hide_title' ) ) :

	/**
	 * HND Hide Title Metabox
	 */
	function hnd_metabox_hide_title() {
		add_meta_box(
			'vast-meta-hide-title-id', __( 'HND Options', 'hnd-plugins' ), 'hnd_metabox_hide_title_control', 'page', 'normal', 'high', array(
				'__block_editor_compatible_meta_box' => true,
				'__back_compat_meta_box'             => false,
			)
		);
	}

endif;

if ( ! function_exists( 'hnd_metabox_hide_title_control' ) ) :

	/**
	 * HND hide title checkbox
	 */
	function hnd_metabox_hide_title_control() {
		global $post;
		wp_nonce_field( 'hnd_nonce', 'hnd_hide_title_nonce' );
		$is_hide = get_post_meta( $post->ID, '_hide_title', true );
		?>
		<p><input type="checkbox" name="hide_title" id="hide_title" value="1" <?php echo esc_attr( ( $is_hide ) ? 'checked="checked"' : '' ); ?>/> <?php esc_html_e( 'Hide Title', 'hnd-plugins' ); ?></strong></p>
		<?php
	}

endif;

if ( ! function_exists( 'hnd_metabox_hide_title_save' ) ) :

	/**
	 * Vast hide title checkbox.
	 *
	 * @param string $post_id Post_id.
	 * @param post   $post The post object.
	 * @param bool   $update Whether this is an existing post being updated or not.
	 */
	function hnd_metabox_hide_title_save( $post_id, $post, $update ) {

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return $post_id;
		}

		if ( ! empty( $_REQUEST['hnd_hide_title_nonce'] ) ) {
			if ( ! wp_verify_nonce( $_REQUEST['hnd_hide_title_nonce'], 'hnd_nonce' ) ) {
				return;
			}
		}

		if ( $update ) {
			$old = get_post_meta( $post_id, '_hide_title', true );
			$new = isset( $_POST['hide_title'] ) ? sanitize_text_field( $_POST['hide_title'] ) : '';

			update_post_meta( $post_id, '_hide_title', $new, $old );
		}
	}

	add_action( 'save_post', 'hnd_metabox_hide_title_save', 10, 3 );

endif;

if ( ! function_exists( 'hnd_body_class' ) ) :

	/**
	 * HND hide title body class.
	 *
	 * @param array $classes Body Class.
	 */
	function hnd_body_class( $classes ) {
		global $post;

		if ( $post ) {
			$is_hide = get_post_meta( $post->ID, '_hide_title', true );
			if ( $is_hide ) {
				$classes[] = 'hide-title';
			}
		}
		$classes[] = 'hnd-menu-stretch' === get_theme_mod( 'hnd-nav-layout' ) ? 'hnd_menu_stretch' : '';

		$classes[] = 'hnd-menu-center' === get_theme_mod( 'hnd-nav-layout' ) ? 'hnd_menu_center' : '';

		$classes[] = 'on' === get_theme_mod( 'hnd-box-arround' ) ? 'hnd_box_arround' : '';

		return $classes;
	}

	add_filter( 'body_class', 'hnd_body_class' );
endif;

if ( is_admin() ) {
	add_action( 'add_meta_boxes', 'hnd_metabox_hide_title' );
}

if ( ! function_exists( 'hnd_metabox_hide_breadcrumbs' ) ) :

	/**
	 * HND Hide Breadcrumbs Metabox
	 */
	function hnd_metabox_hide_breadcrumbs() {
		add_meta_box(
			'vast-meta-hide-breadcrumbs-id', __( 'HND Breadcrumbs Options', 'hnd-plugins' ), 'hnd_metabox_hide_breadcrumbs_control', 'page', 'normal', 'high', array(
				'__block_editor_compatible_meta_box' => true,
				'__back_compat_meta_box'             => false,
			)
		);
	}

	endif;

if ( ! function_exists( 'hnd_metabox_hide_breadcrumbs_control' ) ) :

	/**
	 * HND hide breadcrumbs checkbox
	 */
	function hnd_metabox_hide_breadcrumbs_control() {
		global $post;
		wp_nonce_field( 'hnd_nonce', 'hnd_hide_breadcrumbs_nonce' );
		$is_hide = get_post_meta( $post->ID, '_hide_breadcrumbs', true );

		$as_customizer = get_post_meta( $post->ID, '_as_customizer_breadcrumbs', true );
		$as_customizer = ( empty( $as_customizer ) && ( '0' !== $as_customizer ) ) ? '1' : $as_customizer;
		?>
		<p><input type="checkbox" name="as_customizer_breadcrumbs" id="as_customizer_breadcrumbs" value="1" <?php echo esc_attr( ( '1' === $as_customizer ) ? 'checked="checked"' : '' ); ?>/> <?php esc_html_e( 'Same as Customizer Setting', 'hnd-plugins' ); ?></strong></p>
		<p><input type="checkbox" name="hide_breadcrumbs" id="hide_breadcrumbs" value="1" <?php echo esc_attr( ( $is_hide ) ? 'checked="checked"' : '' ); ?> <?php echo esc_attr( ( '1' === $as_customizer ) ? 'disabled="disabled"' : '' ); ?>/> <?php esc_html_e( 'Hide Breadcrumbs', 'hnd-plugins' ); ?></strong></p>
		<?php
	}

	endif;

if ( ! function_exists( 'hnd_metabox_hide_breadcrumbs_save' ) ) :

	/**
	 * Vast hide breadcrumbs checkbox.
	 *
	 * @param string $post_id Post_id.
	 * @param post   $post The post object.
	 * @param bool   $update Whether this is an existing post being updated or not.
	 */
	function hnd_metabox_hide_breadcrumbs_save( $post_id, $post, $update ) {

		if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
			return $post_id;
		}

		if ( ! empty( $_REQUEST['hnd_hide_breadcrumbs_nonce'] ) ) {
			if ( ! wp_verify_nonce( $_REQUEST['hnd_hide_breadcrumbs_nonce'], 'hnd_nonce' ) ) {
				return;
			}
		}

		if ( $update ) {
			$old = get_post_meta( $post_id, '_as_customizer_breadcrumbs', true );
			$new = isset( $_POST['as_customizer_breadcrumbs'] ) ? sanitize_text_field( $_POST['as_customizer_breadcrumbs'] ) : '0';

			update_post_meta( $post_id, '_as_customizer_breadcrumbs', $new, $old );

			$old = get_post_meta( $post_id, '_hide_breadcrumbs', true );
			$new = isset( $_POST['hide_breadcrumbs'] ) ? sanitize_text_field( $_POST['hide_breadcrumbs'] ) : '';

			update_post_meta( $post_id, '_hide_breadcrumbs', $new, $old );
		}
	}

	add_action( 'save_post', 'hnd_metabox_hide_breadcrumbs_save', 10, 3 );

	endif;

if ( is_admin() ) {
	add_action( 'add_meta_boxes', 'hnd_metabox_hide_breadcrumbs' );
}

if ( ! function_exists( 'hnd_addon_hide_breadcrumbs' ) ) :

	/**
	 * HND hide breadcrumbs filter.
	 *
	 * @param bool $hide_breadcrumbs Hide Breadcrumbs state.
	 */
	function hnd_addon_hide_breadcrumbs( $hide_breadcrumbs ) {
		global $post;

		if ( $post ) {
			$is_hide       = get_post_meta( $post->ID, '_hide_breadcrumbs', true );
			$as_customizer = get_post_meta( $post->ID, '_as_customizer_breadcrumbs', true );
			if ( '1' === $as_customizer ) {
				return $hide_breadcrumbs;
			} else {
				$hide_breadcrumbs = ( '1' === $is_hide ) ? true : false;
			}
		}

		return $hide_breadcrumbs;
	}

	add_filter( 'hide_breadcrumbs', 'hnd_addon_hide_breadcrumbs' );
	endif;


