<?php
/**
 * Theme functions and definitions.
 *
 * Sets up the theme and provides some helper functions
 * For more information on hooks, actions, and filters,
 * see http://codex.wordpress.org/Plugin_API
 *
 * @package Hnd
 */

// Core Constants.
define( 'HND_THEME_DIR', get_template_directory() );
define( 'HND_THEME_URI', get_template_directory_uri() );
// Minimum required PHP version.
define( 'HND_THEME_REQUIRED_PHP_VERSION', '5.2.4' );

/**
 * Set global content width
 *
 * @link https://developer.wordpress.com/themes/content-width/
 */
if ( ! isset( $content_width ) ) {
	$content_width = 900;
}

/**
 * Global variables
 */
$hnd_customizer_panels   = array();
$hnd_customizer_settings = array();
$hnd_customizer_controls = array(
	'hnd-image-selector' => 'Hnd_Image_Selector_Control',
	'hnd-switcher'       => 'Hnd_Switcher_Control',
	'hnd-input-slider'   => 'Hnd_Input_Slider_Control',
	'hnd-alpha-color-picker' => 'Hnd_Alpha_Color_Picker_Control',
	'hnd-icon-picker' => 'Hnd_Icon_Picker_Control',
	'hnd-link' => 'Hnd_Link_Control',
);

/**
 * Load all core theme function files.
 */
require get_parent_theme_file_path( '/inc/helpers.php' );
require get_parent_theme_file_path( '/inc/hooks.php' );
require get_parent_theme_file_path( '/inc/lib/class-hnd-mobile-nav-walker.php' );
require get_parent_theme_file_path( '/inc/lib/webfonts.php' );
require get_parent_theme_file_path( '/inc/lib/class-tgm-plugin-activation.php' );
require get_parent_theme_file_path( '/inc/lib/class-hnd-customizer-config.php' );
require get_parent_theme_file_path( '/inc/lib/class-hnd-customizer-loader.php' );
require get_parent_theme_file_path( '/inc/lib/class-hnd-walker-page.php' );

/**
 * Load panels, sections and settings.
 */
require get_parent_theme_file_path( '/inc/customizer/panels.php' );
require get_parent_theme_file_path( '/inc/customizer/sections.php' );
require get_parent_theme_file_path( '/inc/customizer/settings/general.php' );
require get_parent_theme_file_path( '/inc/customizer/settings/header.php' );
require get_parent_theme_file_path( '/inc/customizer/settings/colors.php' );
require get_parent_theme_file_path( '/inc/customizer/settings/footer.php' );
require get_parent_theme_file_path( '/inc/customizer/settings/default.php' );
require get_parent_theme_file_path( '/inc/customizer/settings/topbar.php' );

/**
 * Class instance init.
 */
$hnd_customizer_loader = new Hnd_Customizer_Loader();

add_action( 'tgmpa_register', 'hnd_register_required_plugins' );

/**
 * Hnd TGMPA
 */
function hnd_register_required_plugins() {

	$plugins = array(
			array(
				'name'                  => esc_html__( 'Contact Form 7','hnd' ),
				'slug'                  => 'contact-form-7',
				'required'              => true,
			),
			array(
				'name'                  => esc_html__( 'King Composer','hnd' ),
				'slug'                  => 'kingcomposer',
				'required'              => true,
			),
			array(
				'name'                  => esc_html__( 'Essential Grid','hnd' ),
				'slug'                  => 'essential-grid',
				'required'              => true,
				'source'                => 'http://demoimporter.detheme.com/plugins/essential-grid.zip',
			),
			array(
				'name'                  => esc_html__( 'WooCommerce','hnd' ),
				'slug'                  => 'woocommerce',
				'required'              => false,
			),
			array(
				'name'                  => esc_html__( 'QuadMenu','hnd' ),
				'slug'                  => 'quadmenu',
				'required'              => false,
			),
			array(
				'name'                  => esc_html__( 'Slider Revolution','hnd' ),
				'slug'                  => 'slider-revolution',
				'required'              => true,
				'source'                => 'http://demoimporter.detheme.com/plugins/slider-revolution.zip',
			),
			array(
				'name'                  => esc_html__( 'Footer Builder for Vast','hnd' ),
				'slug'                  => 'vast-footer-builder',
				'required'              => true,
				'source'                => 'http://demoimporter.detheme.com/plugins/vast-footer-builder.zip',
			),
			array(
				'name'                  => esc_html__( 'HND Addon','hnd' ),
				'slug'                  => 'hnd-addon',
				'required'              => true,
				'source'                => 'http://demoimporter.detheme.com/hnd/plugins/hnd-addon.zip',
			),
			array(
				'name'                  => esc_html__( 'Vast Demo Import','hnd' ),
				'slug'                  => 'vast-demo-import',
				'required'              => true,
				'source'                => 'http://demoimporter.detheme.com/hnd/plugins/vast-demo-import.zip',
			),
		);

	$config = array(
		'id'           => 'hnd',                 // Unique ID for hashing notices for multiple instances of TGMPA.
		'default_path' => '',                      // Default absolute path to bundled plugins.
		'menu'         => 'tgmpa-install-plugins', // Menu slug.
		'has_notices'  => true,                    // Show admin notices or not.
		'dismissable'  => true,                    // If false, a user cannot dismiss the nag message.
		'dismiss_msg'  => '',                      // If 'dismissable' is false, this message will be output at top of nag.
		'is_automatic' => false,                   // Automatically activate plugins after installation or not.
		'message'      => '',                      // Message to output right before the plugins table.
	);

	tgmpa( $plugins, $config );

}
